summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/dmsbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/dmsbox.h')
-rw-r--r--kstars/kstars/dmsbox.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kstars/kstars/dmsbox.h b/kstars/kstars/dmsbox.h
index 81590a4e..d12c0a12 100644
--- a/kstars/kstars/dmsbox.h
+++ b/kstars/kstars/dmsbox.h
@@ -47,12 +47,12 @@ TQ_PROPERTY (bool degType READ degType WRITE setDegType)
public:
/**Constructor for the dmsBox object.
*@param tqparent pointer to the tqparent TQWidget
*@param ni the name of the object
*@param deg if TRUE use deg/arcmin/arcsec; otherwise
* use hours/min/sec.
*/
- dmsBox(TQWidget *tqparent, const char *ni=0, bool deg=TRUE);
+ dmsBox(TQWidget *parent, const char *ni=0, bool deg=TRUE);
/**Destructor (empty)*/
~dmsBox();
@@ -47,12 +47,12 @@ TQ_PROPERTY (bool degType READ degType WRITE setDegType)
public:
/**Constructor for the dmsBox object.
- *@param tqparent pointer to the tqparent TQWidget
+ *@param parent pointer to the parent TQWidget
*@param ni the name of the object
*@param deg if TRUE use deg/arcmin/arcsec; otherwise